pub struct ServerJobQueue {
jobs: SyncMutex<Vec<Box<dyn ServerJob>>>,
}Expand description
Tick-owned job queue.
Fields
jobs: SyncMutex<Vec<Box<dyn ServerJob>>>Implementations
Sourceimpl ServerJobQueue
impl ServerJobQueue
Sourcepub fn spawn(&self, job: impl ServerJob + 'static)
pub fn spawn(&self, job: impl ServerJob + 'static)
Adds a job to be polled on the next server job tick.
Sourcepub fn poll_now_or_spawn(
&self,
server: Weak<Server>,
tick_count: u64,
runs_normally: bool,
job: impl ServerJob + 'static,
) -> JobPoll
pub fn poll_now_or_spawn( &self, server: Weak<Server>, tick_count: u64, runs_normally: bool, job: impl ServerJob + 'static, ) -> JobPoll
Polls a job immediately from a known safe point, queuing it only if it remains pending.
Sourcepub fn cancel_all(&self)
pub fn cancel_all(&self)
Cancels and removes all queued jobs.
Sourcepub fn tick(
&self,
server: Weak<Server>,
tick_count: u64,
runs_normally: bool,
) -> ServerJobTickStats
pub fn tick( &self, server: Weak<Server>, tick_count: u64, runs_normally: bool, ) -> ServerJobTickStats
Polls queued jobs from the server game tick.
fn tick_with_context( &self, context: &mut ServerJobContext, ) -> ServerJobTickStats
fn poll_now_or_spawn_with_context( &self, context: &mut ServerJobContext, job: impl ServerJob + 'static, ) -> JobPoll